==> r-s-tags-input-1.0.0.tgz: package/es/tag.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { Input, Label, Form, Icon } from 'semantic-ui-react';

var Container = function Container(props) {
    if (props.color === '') {
        var color = props.color,
            others = _objectWithoutProperties(props, ['color']);

        return React.createElement(
            Label,
            others,
            props.children
        );
    }
    return React.createElement(
        Label,
        props,
        props.children
    );
};

var _default = (_temp = _class = function (_React$Component) {
    _inherits(_default, _React$Component);

    function _default() {
        _classCallCheck(this, _default);

        return _possibleConstructorReturn(this, _React$Component.apply(this, arguments));
    }

    _default.prototype.render = function render() {
        var _this2 = this;

        var _props = this.props,
            removable = _props.removable,
            onRemoveClick = _props.onRemoveClick,
            others = _objectWithoutProperties(_props, ['removable', 'onRemoveClick']);

        return React.createElement(
            Container,
            _extends({ size: 'small' }, others),
            this.props.text,
            removable && React.createElement(Icon, {
                name: 'delete',
                link: true,
                onClick: function onClick() {
                    return onRemoveClick(_this2.props.text);
                }
            })
        );
    };

    return _default;
}(React.Component), _class.propTypes = {
    text: PropTypes.string.isRequired,
    color: PropTypes.string,
    removable: PropTypes.bool,
    onRemoveClick: PropTypes.func
}, _class.defaultProps = {
    color: '',
    removable: false,
    onRemoveClick: function onRemoveClick() {}
}, _temp);

export { _default as default };

==> r-s-tags-input-1.0.4.tgz: package/es/tag.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { Input, Label, Form, Icon } from 'semantic-ui-react';

var Container = function Container(props) {
    if (props.color === '') {
        var color = props.color,
            others = _objectWithoutProperties(props, ['color']);

        return React.createElement(
            Label,
            others,
            props.children
        );
    }
    return React.createElement(
        Label,
        props,
        props.children
    );
};

var _default = (_temp = _class = function (_React$Component) {
    _inherits(_default, _React$Component);

    function _default() {
        _classCallCheck(this, _default);

        return _possibleConstructorReturn(this, _React$Component.apply(this, arguments));
    }

    _default.prototype.render = function render() {
        var _this2 = this;

        var _props = this.props,
            removable = _props.removable,
            onRemoveClick = _props.onRemoveClick,
            others = _objectWithoutProperties(_props, ['removable', 'onRemoveClick']);

        return React.createElement(
            Container,
            _extends({ size: 'small' }, others, { style: { marginBottom: '1px', float: 'left', display: 'block' } }),
            this.props.text,
            removable && React.createElement(Icon, {
                name: 'delete',
                link: true,
                onClick: function onClick() {
                    return onRemoveClick(_this2.props.text);
                }
            })
        );
    };

    return _default;
}(React.Component), _class.propTypes = {
    text: PropTypes.string.isRequired,
    color: PropTypes.string,
    removable: PropTypes.bool,
    onRemoveClick: PropTypes.func
}, _class.defaultProps = {
    color: '',
    removable: false,
    onRemoveClick: function onRemoveClick() {}
}, _temp);

export { _default as default };
